pub struct PrincipalBytes {
pub flag: u8,
pub len: u64,
pub inner: Vec<u8>,
}Fields
flag: u8len: u64inner: Vec<u8>Trait Implementations
Sourceimpl BinRead for PrincipalBytes
impl BinRead for PrincipalBytes
Sourcetype Args = ()
type Args = ()
The type of arguments needed to be supplied in order to read this type, usually a tuple. Read more
Sourcefn read_options<R>(
__binread_generated_var_reader: &mut R,
__binread_generated_var_options: &ReadOptions,
__binread_generated_var_arguments: <PrincipalBytes as BinRead>::Args,
) -> Result<PrincipalBytes, Error>
fn read_options<R>( __binread_generated_var_reader: &mut R, __binread_generated_var_options: &ReadOptions, __binread_generated_var_arguments: <PrincipalBytes as BinRead>::Args, ) -> Result<PrincipalBytes, Error>
Read the type from the reader
Sourcefn read<R>(reader: &mut R) -> Result<Self, Error>
fn read<R>(reader: &mut R) -> Result<Self, Error>
Read the type from the reader while assuming no arguments have been passed Read more
Sourcefn read_args<R>(reader: &mut R, args: Self::Args) -> Result<Self, Error>
fn read_args<R>(reader: &mut R, args: Self::Args) -> Result<Self, Error>
Read the type from the reader using the specified arguments
fn after_parse<R>( &mut self, _: &mut R, _: &ReadOptions, _: Self::Args, ) -> Result<(), Error>