Module ser

Module ser 

Serialize a Rust data structure to Candid binary format

Structs

Compound
IDLBuilder
Use this struct to serialize a sequence of Rust values (heterogeneous) to IDL binary message.
TypeSerialize
A structure for serializing Rust values to IDL types.
ValueSerializer
A structure for serializing Rust values to IDL.