Module typing

Module typing 

Structs

Env

Functions

ast_to_type
Convert candid AST to internal Type
check_file
Type check did file including the imports.
check_init_args
Type check init args extracted from canister metadata candid:args. Need to provide main_env, because init args may refer to variables from the main did file.
check_prog
Type check IDLProg and adds bindings to type environment. Returns the main actor if present. This function ignores the imports.
check_type
pretty_check_file