Serialize a Rust data structure to Candid binary format
Structs
- Compound
- IDLBuilder
- Use this struct to serialize a sequence of Rust values (heterogeneous) to IDL binary message.
- Type
Serialize - A structure for serializing Rust values to IDL types.
- Value
Serializer - A structure for serializing Rust values to IDL.