Structs
Functions
- ast_
to_ type - Convert candid AST to internal Type
- check_
file - Type check did file including the imports.
- check_
init_ args - Type check init args extracted from canister metadata candid:args.
Need to provide
main_env, because init args may refer to variables from the main did file. - check_
prog - Type check IDLProg and adds bindings to type environment. Returns the main actor if present. This function ignores the imports.
- check_
type - pretty_
check_ file